@@ -24,15 +24,14 @@
  */
 
 var {Cc, Ci, Cu, Cm, Cr} = require("chrome");
-var xpcom = require("xpcom");
-Cu.import("resource://gre/modules/XPCOMUtils.jsm"); 
 
 var jsChecker = require("js_checker/js_checker");
 
 const types = require("js_checker/constant_types");
 var checkTypes = types.checkTypes;
 
-
+// check if scripts embedded dynamically have a jsWebLabel entry indexed by referrer.
+var jsWebLabelEntries = require("html_script_finder/js_web_labels").jsWebLabelEntries;
 
 var htmlParser = require("html_script_finder/html_parser");
 
@@ -41,7 +40,6 @@ var allowedRef = require('http_observer/allowed_referrers').allowedReferrers;
 
 var acceptedScripts = require("script_entries/accepted_scripts").acceptedScripts;
 
-
 // node.js url module. Makes it easier to resolve 
 // urls in that datauri loaded dom
 var urlHandler = require("url_handler/url_handler");
@@ -69,6 +67,8 @@ var processResponseObject = {
     init: function (listener, resInfo) {
 	this.resInfo = resInfo;
 	this.req = resInfo.request;
+        /* needed for this.req.referrer */
+        this.req.QueryInterface(Ci.nsIHttpChannel);
 	this.listener = listener;
 	this.setData();
 	this.setContentType();
@@ -85,12 +85,12 @@ var processResponseObject = {
     },
 
     /**
-     * Join the data gathered from onDataAvailable.
+     * Gather the data gathered from onDataAvailable.
      */
     setData: function () {
 
-	this.data = this.listener.receivedData.join('');
-
+	this.data = this.resInfo.receivedData;
+        //console.log("\n\nDump of whole data:\n\n", this.data, "\n\n end of dump");
 	// Prevents the http response body from being empty,
 	// which would throw an error.
 	if (this.data == '' || this.data == undefined) {
@@ -114,6 +114,7 @@ var processResponseObject = {
      * set referrer if applicable.
      */
     setUrls: function() {
+
 	if (this.req.URI != undefined) {
 	    this.fragment = urlHandler.getFragment(this.req.URI.spec);
 	    //console.log('fragment is', this.fragment);
@@ -132,17 +133,25 @@ var processResponseObject = {
     processHTML: function() {
 
 	var charset = this.req.contentCharset, myParser;
+
+        if (this.req.contentCharset != undefined && this.req.contentCharset != "") {
+            charset = this.req.contentCharset;
+        } else {
+            charset = "";
+        }
 	//console.log('charset is', charset);
 	//console.log('responseStatus for', this.url, 'is', this.req.responseStatus);
 
 	// send data to htmlParser, and pass on modified data to
 	// originalListener.
 	myParser = htmlParser.htmlParser().parse(this.data, 
-						 charset, 
+						 charset,
+                                                 this.contentType,
 						 this.url,
 						 this.fragment,
 						 this.req.responseStatus,
 						 this.htmlParseCallback.bind(this));
+
     },
 
     /**
@@ -159,17 +168,20 @@ var processResponseObject = {
 
 	try {
 
-	    this.listener.originalListener.onDataAvailable(this.req, 
-							   this.resInfo.context, 
-							   result.newInputStream(0), 0, len);
-	} catch (e) {
+	    this.listener.onDataAvailable(this.req, 
+					  this.resInfo.context, 
+					  result.newInputStream(0), 0, len);
+            
 
+	} catch (e) {
+            
 	    this.req.cancel(this.req.NS_BINDING_ABORTED);
 
 	}
 
-	this.listener.originalListener.onStopRequest(this.req, 
-						     this.resInfo.context, this.resInfo.statusCode);
+        this.listener.onStopRequest(this.req, 
+				    this.resInfo.context, this.resInfo.statusCode);
+
     },
 
     /**
@@ -180,12 +192,20 @@ var processResponseObject = {
 	var checker, check, jsCheckString,
 	    that = this;
 	//var start = Date.now(), end;
-
 	try {
+	    // make sure script isn't already listed as free
+	    // in a JS web labels table.
+	    if (this.checkJsWebLabelsForScript()) { 
+		// this is free. we are done.
+		this.jsListenerCallback();
+		return; 
 
+	    }
+	    
+	    // analyze javascript in response.
 	    checker = jsChecker.jsChecker();
-
 	    check = checker.searchJs(this.data, function () {
+                //console.log("Has been analyzing", that.data);
 					 that.processJsCallback(checker);
 				     });
 
@@ -195,19 +215,62 @@ var processResponseObject = {
 
 	    // any error is considered nontrivial.
 	    //console.log('js error in js app, removing script', e);
-
+            console.log("error", e, e.lineNumber);
 	    // modify data that will be sent to the browser.
 	    this.data = '// LibreJS: JS mime-type. Script removed.';
 	    this.jsListenerCallback();
 	}
 
     },
+
+    /**
+     * checkJsWebLabelsForScript
+     * 
+     * check whether script that's been received has an entry
+     * in a js web labels table (lookup referrer.)
+     *  
+     */
+    checkJsWebLabelsForScript: function () {
+
+	//console.log('checking script', this.url);
+	//console.log('current list is', JSON.stringify(jsWebLabelEntries));
+	if (jsWebLabelEntries[this.referrer] != undefined) {
+
+	    var scriptList = jsWebLabelEntries[this.referrer],
+	    i = 0,
+            len = scriptList.length;
+	    
+	    for (; i < len; i++) {
+
+		if (scriptList[i].fileUrl === this.url &&
+		    scriptList[i].free === true) {
+
+		    //console.log(this.url, "is free and dynamic!");
+
+		    var scriptObj = {inline: false,
+				     contents: this.url};
+
+		    acceptedScripts.addAScript(this.req.referrer.spec, scriptObj);
+
+		    return true;
+
+		}
+
+	    }
+	    
+ 	    
+	}
+	
+    },
+    
     processJsCallback: function(checker) {
 	try {
 	    var scriptObj;
-
+	    
 	    var jsCheckString = checker.parseTree.freeTrivialCheck;
-
+	    // for testing only.
+	    // var jsCheckString = checkTypes.FREE;
+    
 	    if (jsCheckString === checkTypes.NONTRIVIAL_LOCAL ||
 		jsCheckString === checkTypes.NONTRIVIAL_GLOBAL) {
 		scriptObj = {inline: false,
@@ -215,6 +278,7 @@ var processResponseObject = {
 			     removalReason: 'nontrivial'};
 
 		removedScripts.addAScript(this.req.referrer.spec, scriptObj);
+
 		// modify data that will be sent to the browser.
 		this.data = '// LibreJS: JS mime-type. Script removed.';
 
@@ -266,8 +330,10 @@ var processResponseObject = {
 	    if (this.referrer != undefined &&
 		jsMimeTypeRe.test(this.contentType) &&
 		!allowedRef.urlInAllowedReferrers(this.referrer) &&
-	        !(acceptedScripts.isFound(this.referrer, {inline: false, contents: this.url}))) {
-
+	        !(acceptedScripts.isFound(this.referrer, {inline: false, contents: this.url})) &&
+	       !(acceptedScripts.isFound(this.referrer, {inline:false, contents:this.req.originalURI.spec}))) {
+		
+                // console.log('process js triggered for', this.url);
 		this.processJS();
 
 	    } else {
@@ -289,17 +355,17 @@ var processResponseObject = {
 	this.binaryOutputStream.writeBytes(this.data, len);
 	
 	try {
-	    this.listener.originalListener.onDataAvailable(this.req, 
-							   this.resInfo.context, 
-							   this.storageStream.newInputStream(0), 
-							   0, len);
+	    this.listener.onDataAvailable(this.req, 
+					  this.resInfo.context, 
+					  this.storageStream.newInputStream(0), 
+					  0, len);
 	} catch (e) {
 	    this.req.cancel(this.req.NS_BINDING_ABORTED);
 	}
-
-	this.listener.originalListener.onStopRequest(this.req, 
-						     this.resInfo.context, 
-						     this.resInfo.statusCode);
+        
+	this.listener.onStopRequest(this.req, 
+				    this.resInfo.context, 
+				    this.resInfo.statusCode);
 
     }
     
