@@ -45,7 +45,7 @@ var urlUtils = {
 	    // when url has query string and fragment
 	    // the add-on wouldn't remove cache entry
 	    // properly.
-	    delete parse.hash
+	    delete parse.hash;
 	}
 	return nodeJsUrl.format(parse);
     },
